SlotMode

Enum SlotMode 

pub enum SlotMode {
    Mono,
    Stereo,
}
I2S channel slot mode.

See the documentation for the mode of operation to see how this affects the data layout:

Variants



Mono

Mono mode:

  • When transmitting, transmit the same data in all slots.
  • When receiving, only receive data from the first slot.


Stereo

Stereo mode:

  • When transmitting, transmit different data in each slot.
  • When receiving, receive data from all slots.