PdmTxClkConfig

Struct PdmTxClkConfig 

pub struct PdmTxClkConfig { /* private fields */ }
The I2s pulse density modulation (PDM) mode transmit clock configuration.

Note

The PDM transmit clock can only be set to the following two upsampling rate configurations:

  • upsampling_fp = 960, upsampling_fs = sample_rate_hz / 100. In this case, Fpdm = 128 * 48000 = 6.144 MHz.
  • upsampling_fp = 960, upsampling_fs = 480. In this case, Fpdm = 128 * sample_rate_hz.

If the PDM receiver does not use the PDM serial clock, the first configuration should be used. Otherwise, use the second configuration.

Implementations

Source

impl PdmTxClkConfig

pub fn from_sample_rate_hz(sample_rate_hz: u32) -> Self

Create a new PDM mode transmit clock configuration from the specified sample rate in Hz. This will set the clock source to PLL_F160M, the MCLK multiple to 256 times the sample rate, upsample_fp to 960, and upsample_fs to 480.

pub fn sample_rate_hz(self, sample_rate_hz: u32) -> Self

Set the sample rate on this PDM mode transmit clock configuration.

pub fn clk_src(self, clk_src: ClockSource) -> Self

Set the clock source on this PDM mode transmit clock configuration.

pub fn mclk_multiple(self, mclk_multiple: MclkMultiple) -> Self

Set the MCLK multiple on this PDM mode transmit clock configuration.

pub fn upsample(self, upsample_fp: u32, upsample_fs: u32) -> Self

Set the upsampling parameters on this PDM mode transmit clock configuration.