PdmTxSlotConfig

Struct PdmTxSlotConfig 

pub struct PdmTxSlotConfig { /* private fields */ }
PDM mode channel transmit slot configuration.

Note

The slot_mode and line_mode (microcontrollers new than ESP32) or slot_mask (ESP32) cause data to be interpreted in different ways, as noted below.

Assuming the buffered data contains the following samples (where a sample may be 1, 2, 3, or 4 bytes, depending on data_bit_width):

d[0]d[1]d[2]d[3]d[4]d[5]d[6]d[7]
1112131415161718

The actual data on the line will be:

All microcontrollers except ESP32

line_modeslot_modeLineTransmitted Data
WS LowWS HighWS LowWS HighWS LowWS HighWS LowWS High
OneLineCodecMono dout110120130140
Stereodout1112131415161718
OneLineDac Mono dout1111121213131414
TwoLineDac Monodout1212141416161818
dout200000000
Stereodout1212141416161818
dout21111131315151717

ESP32

slot_modeslot_maskTransmitted Data
WS LowWS HighWS LowWS HighWS LowWS HighWS LowWS High
Mono Left 110120130140
Right011012013014
Both1112131415161718
Mono Left1111131315151717
Right1212141416161818
Both 1112131415161718

Modes combinations other than SlotMode::Mono/PdmSlotMask::Both, SlotMode::Stereo/PdmSlotMask::Left, and SlotMode::Stereo/PdmSlotMask::Right are unlikely to be useful since it requires precise demutiplexing on the bit stream based on the WS clock.

For details, refer to the ESP-IDF Programming Guide PDM Tx Usage details for your specific microcontroller:

Implementations

Source

impl PdmTxSlotConfig

pub fn from_slot_mode(slot_mode: SlotMode) -> Self

Configure the PDM mode channel transmit slot configuration for the specified slot mode in 2 slots.

This sets the sigma-delta, low-pass, and sinc scaling to None.

For hardware version 1, the high-pass filter scaling is set to None.

For hardware version 2, the high-pass filter is enabled, scaled to dividing by 2 and set to 35.5 Hz.

pub fn slot_mode(self, slot_mode: SlotMode) -> Self

Sets the slot mode on this PDM transmit slot configuration.

pub fn sd_prescale(self, sd_prescale: u32) -> Self

Sets the sigma-delta filter prescale on this PDM transmit slot configuration.

pub fn sd_scale(self, sd_scale: PdmSignalScale) -> Self

Sets the sigma-delta filter scaling on this PDM transmit slot configuration.

pub fn hp_scale(self, hp_scale: PdmSignalScale) -> Self

Sets the high-pass filter scaling on this PDM transmit slot configuration.

pub fn lp_scale(self, lp_scale: PdmSignalScale) -> Self

Sets the low-pass filter scaling on this PDM transmit slot configuration.

pub fn sinc_scale(self, sinc_scale: PdmSignalScale) -> Self

Sets the sinc filter scaling on this PDM transmit slot configuration.

pub fn line_mode(self, line_mode: PdmTxLineMode) -> Self

Sets the PDM transmit line mode on this PDM transmit slot configuration.

pub fn hp_enable(self, hp_enable: bool) -> Self

Sets the high-pass filter enable on this PDM transmit slot configuration.

pub fn hp_cutoff_freq(self, hp_cutoff_freq: f32) -> Self

Sets the high-pass filter cutoff frequency on this PDM transmit slot configuration.

pub fn sd_dither(self, sd_dither: u32, sd_dither2: u32) -> Self

Sets the sigma-delta filter dither on this PDM transmit slot configuration.